@@ -5,6 +5,7 @@
 
 __all__ = (
     'BetterLineEdit',
+    'BetterTextBrowser',
     'HistoryComboBox',
     'LicenseViewer',
 )
@@ -12,6 +13,7 @@ __all__ = (
 from collections import defaultdict
 from collections.abc import Callable
 from collections.abc import Sequence
+from typing import Optional
 
 from PySide6.QtCore import *
 from PySide6.QtGui import *
@@ -19,6 +21,7 @@ from PySide6.QtWidgets import *
 
 from ..constants import *
 from ..utils import current_requirement_licenses
+from .utils import scroll_to_top
 
 _PARENT_PACKAGE: str = __package__.split('.', maxsplit=1)[0]
 
@@ -26,21 +29,39 @@ _PARENT_PACKAGE: str = __package__.split('.', maxsplit=1)[0]
 class BetterLineEdit(QLineEdit):
     """A :py:class:`QLineEdit` with an added paste listener."""
 
-    def __init__(self, *args, pasted: Callable | None = None, **kwargs):
+    def __init__(self, *args, pasted: Optional[Callable] = None, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         if pasted is not None:
             vars(self)['pasted'] = pasted
 
-    def pasted(self):
+    def pasted(self) -> None:
         """Function called when a paste key combo is detected."""
 
-    def keyPressEvent(self, event: QKeyEvent):
+    def keyPressEvent(self, event: QKeyEvent) -> None:
         """Call self.pasted on paste."""
         super().keyPressEvent(event)
         if event.matches(QKeySequence.Paste):
             self.pasted()
 
 
+class BetterTextBrowser(QTextBrowser):
+    """:py:class:`QTextBrowser` with ability to map keys to :py:class:`Callable`'s."""
+
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        self.key_callable_map: defaultdict[int, Callable] = defaultdict(lambda: lambda: None)
+
+    # noinspection PyTypeChecker
+    def connect_key_to(self, key: Qt.Key, func: Callable) -> None:
+        """Connect a :py:class:`Callable` to a key press."""
+        self.key_callable_map[int(key)] = func
+
+    def keyPressEvent(self, event: QKeyEvent) -> None:
+        """Execute :py:class:`Callable` mapped to the key press."""
+        super().keyPressEvent(event)
+        self.key_callable_map[event.key()]()
+
+
 class HistoryComboBox(QComboBox):
     """Editable :py:class:`QComboBox` acting as a history wrapper over :py:class:`BetterLineEdit`; has no duplicate values."""
     line_edit_class = BetterLineEdit
@@ -70,30 +91,12 @@ class HistoryComboBox(QComboBox):
 
         super().addItem(text, **kwargs)
 
-    def addItems(self, texts: Sequence[str]) -> None:
+    def addItems(self, texts: Sequence[str], **_) -> None:
         """self.addItem for text in texts."""
         for text in texts:
             self.addItem(text)
 
 
-class BetterTextBrowser(QTextBrowser):
-    """:py:class:`QTextBrowser` with ability to map keys to :py:class:`Callable`'s."""
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.key_callable_map: defaultdict[int, Callable] = defaultdict(lambda: lambda: None)
-
-    # noinspection PyTypeChecker
-    def connect_key_to(self, key: Qt.Key, func: Callable):
-        """Connect a :py:class:`Callable` to a key press."""
-        self.key_callable_map[int(key)] = func
-
-    def keyPressEvent(self, event: QKeyEvent) -> None:
-        """Execute :py:class:`Callable` mapped to the key press."""
-        super().keyPressEvent(event)
-        self.key_callable_map[event.key()]()
-
-
 class LicenseViewer(QWidget):
     """Widget that formats and shows the project's license file."""
     LICENSE_DATA = current_requirement_licenses(_PARENT_PACKAGE)
@@ -161,20 +164,14 @@ class LicenseViewer(QWidget):
             self.current_license_index = len(self.LICENSE_DATA) - 1
         self.view_current_index()
 
-    def scroll_to_top(self) -> None:
-        """Move text cursor to top of text document."""
-        cursor = self.license_text_edit.textCursor()
-        cursor.setPosition(0)
-        self.license_text_edit.setTextCursor(cursor)
-
     def view_current_index(self) -> None:
         """Views the license data at the current index."""
-        self.view_package(tuple(self.LICENSE_DATA.keys())[self.current_license_index])
+        self.view_package(tuple(self.LICENSE_DATA)[self.current_license_index])
 
     def view_package(self, package: str) -> None:
         """Views the license data of the given package name."""
         license_text = self.LICENSE_DATA[package][1] or 'LICENSE TEXT NOT FOUND -- COULD BE DUE TO EDITABLE INSTALLATION'
-        self.current_license_index = tuple(self.LICENSE_DATA.keys()).index(package)
+        self.current_license_index = tuple(self.LICENSE_DATA).index(package)
         self.license_label.setText(f'{package} -- "{self.LICENSE_DATA[package][0]}" License')
         self.license_index_label.setText(f'{self.current_license_index + 1} of {len(self.LICENSE_DATA)}')
 
@@ -192,4 +189,4 @@ class LicenseViewer(QWidget):
         stripped_output = stripped_output.strip()
         self.license_text_edit.setHtml(f'<body style="white-space: pre-wrap"><center>{stripped_output}</center></body>')
 
-        self.scroll_to_top()
+        scroll_to_top(self.license_text_edit)
