@@ -21,9 +21,11 @@ from .._version import __version__
 from ..client import Client
 from ..client import HTTP_CODE_MAP
 from ..constants import *
-from ..tomlfile import TomlFile
+from ..events import *
+from ..tomlfile import TomlFile, TomlEvents
 from .app import *
 from .menus import *
+from .utils import scroll_to_top
 from .widgets import *
 
 
@@ -44,10 +46,12 @@ class SettingsWindow(QWidget):
         self.setWindowIcon(QIcon(str(HI_RESOURCE_PATH / 'icons/settings.ico')))
         self.resize(size)
         self.setFixedWidth(self.width())
-        self.settings.hook_event('$fail:import', lambda: QMessageBox.warning(
-            self, *(self.translator(*key) for key in (
+
+        # Create a self.translator DeferredCallable with every tuple acting as arguments.
+        EventBus['settings'].subscribe(DeferredCallable(
+            QMessageBox.warning, self, *(DeferredCallable(self.translator, *key) for key in (
                 ('warnings.settings.import_failure.title',), ('warnings.settings.import_failure.description', self.settings.path)))
-        ))
+        ), TomlEvents.Fail, event_predicate=lambda event: event.failure == 'import')
 
         self.theme_dropdown:          QComboBox
         self.aspect_ratio_dropdown:   QComboBox
@@ -278,7 +282,6 @@ class AppWindow(QMainWindow):
         self.client:                Client = client
         self.clipboard:             QClipboard = app.clipboard()
         self.current_image:         QPixmap | None = None
-        self._clicked_input_field:  bool = False
         self.detached:              dict[str, QMainWindow | None] = {'media': None, 'text': None}
         self.setWindowTitle(self.APP.translator('app.title', __version__))
         self.setWindowIcon(QIcon(str(HI_RESOURCE_PATH / 'icons/hi.ico')))
@@ -286,13 +289,19 @@ class AppWindow(QMainWindow):
 
         self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
 
-        self.input_field:   HistoryComboBox
-        self.media_output:  QGraphicsView
-        self.text_output:   QTextBrowser
-        self.clear_picture: QPushButton
-        self.copy_picture:  QPushButton
-        self.clear_text:    QPushButton
-        self.copy_text:     QPushButton
+        self.input_field:         HistoryComboBox
+        self.media_frame:         QFrame
+        self.image_size_label:    QLabel
+        self.image_detach_button: QPushButton
+        self.media_output:        QGraphicsView
+        self.text_frame:          QFrame
+        self.text_size_label:     QLabel
+        self.text_detach_button:  QPushButton
+        self.text_output:         BetterTextBrowser
+        self.clear_picture:       QPushButton
+        self.copy_picture:        QPushButton
+        self.clear_text:          QPushButton
+        self.copy_text:           QPushButton
 
         self._init_toolbar()
         self._init_ui()
@@ -312,10 +321,10 @@ class AppWindow(QMainWindow):
             menu.show()
 
         toolbar = QToolBar('Toolbar', self)
-        file = QAction('File', self, triggered=lambda: context_menu_handler(FileContextMenu))
+        file = QAction('File', self, triggered=DeferredCallable(context_menu_handler, FileContextMenu))
         settings = QAction('Settings', self, triggered=self.open_settings_window)
-        tools = QAction('Tools', self, triggered=lambda: context_menu_handler(ToolsContextMenu))
-        help_ = QAction('Help', self, triggered=lambda: context_menu_handler(HelpContextMenu))
+        tools = QAction('Tools', self, triggered=DeferredCallable(context_menu_handler, ToolsContextMenu))
+        help_ = QAction('Help', self, triggered=DeferredCallable(context_menu_handler, HelpContextMenu))
 
         self.addToolBar(Qt.ToolBarArea.TopToolBarArea, toolbar)
         for action in (file, settings, tools, help_):
@@ -405,6 +414,21 @@ class AppWindow(QMainWindow):
             if self.clipboard is not None:
                 self.clipboard.setText(self.text_output.toPlainText())
 
+        def next_in_history() -> None:
+            """View the next license."""
+            # Qt automatically rolls over to -1, so we handle it like prev_in_history
+            self.input_field.setCurrentIndex(self.input_field.currentIndex() + 1)
+            if self.input_field.currentIndex() < 0:
+                self.input_field.setCurrentIndex(0)
+            self.use_input()
+
+        def prev_in_history() -> None:
+            """View the previous license."""
+            self.input_field.setCurrentIndex(self.input_field.currentIndex() - 1)
+            if self.input_field.currentIndex() < 0:
+                self.input_field.setCurrentIndex(self.input_field.count() - 1)
+            self.use_input()
+
         self.input_field:         HistoryComboBox = HistoryComboBox()
         self.media_frame:         QFrame = QFrame()
         self.image_size_label:    QLabel = QLabel(self.APP.translator('gui.outputs.image.label_empty'))
@@ -413,7 +437,7 @@ class AppWindow(QMainWindow):
         self.text_frame:          QFrame = QFrame()
         self.text_size_label:     QLabel = QLabel(self.APP.translator('gui.outputs.text.label_empty'))
         self.text_detach_button:  QPushButton = QPushButton(self.APP.translator('gui.outputs.detach'), clicked=toggle_text_detach)
-        self.text_output:         QTextBrowser = QTextBrowser()
+        self.text_output:         BetterTextBrowser = BetterTextBrowser()
         self.clear_picture:       QPushButton = QPushButton(self.APP.translator('gui.outputs.clear'), clicked=clear_current_pixmap)
         self.copy_picture:        QPushButton = QPushButton(self.APP.translator('gui.outputs.image.copy'), clicked=copy_current_pixmap)
         self.clear_text:          QPushButton = QPushButton(self.APP.translator('gui.outputs.clear'), clicked=clear_current_text)
@@ -421,10 +445,12 @@ class AppWindow(QMainWindow):
         subdomain_field:          QLineEdit = QLineEdit(self.client.sub_host)
         root_folder_field:        QLineEdit = QLineEdit(self.client.parent_path)
         get_button:               QPushButton = QPushButton(self.APP.translator('gui.input_field.get'), clicked=self.use_input)
-        scan_button:              QPushButton = QPushButton(self.APP.translator('gui.input_field.scan'), clicked=lambda: self.use_input(scan=True))
+        scan_button:              QPushButton = QPushButton(self.APP.translator('gui.input_field.scan'), clicked=DeferredCallable(self.use_input, scan=True))
 
         self.input_field.lineEdit().returnPressed.connect(self.use_input)  # Connect pressing enter while in the line edit to use_input
         self.text_output.anchorClicked.connect(lambda e: self.navigate_to(e.toDisplayString()))
+        self.text_output.connect_key_to(Qt.Key_Left, prev_in_history)
+        self.text_output.connect_key_to(Qt.Key_Right, next_in_history)
 
         main_widget = QWidget()
         layout = QGridLayout()
@@ -531,8 +557,11 @@ class AppWindow(QMainWindow):
 
         :param scan: Whether to recursively scan a resource.
         """
-        self._clicked_input_field = True
         user_input = self.input_field.currentText()
+        scroll_to_top(self.text_output)
+        if not user_input:
+            return
+
         if '/file/' not in user_input:
             if user_input.endswith(('png', 'jpg', 'jpeg', 'webp', 'gif')):
                 user_input = f'images/file/{user_input}'
@@ -567,12 +596,12 @@ class AppWindow(QMainWindow):
 
                     output = data
                     replaced = set()
-
                     for match in HI_PATH_PATTERN.finditer(data):
                         match = match[0].replace('"', '')
                         if match not in replaced:
                             output = output.replace(match, f'<a href="{match}" style="color: #2A5DB0">{match}</a>')
                             replaced.add(match)
+
                     self.text_output.setHtml(f'<body style="white-space: pre-wrap">{output}</body>')
                     self.text_size_label.setText(self.APP.translator('gui.outputs.text.label',
                                                                      len(data.splitlines()), len(data),
